# dsHypoGen v1.0, a dual-stage hypocycloid reducer parameter generator

# Copyright (c) 2013 Derek Hugger

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.



import os
from sys import platform as _platform
if _platform == "linux" or _platform == "linux2":
    os.system('clear')  # Linux
elif _platform == "darwin":
   os.system('clear')   # Mac OS X
elif _platform == "win32":
    os.system('cls')    # Windows

print '''This program calculates the number of pins and lobes required
in each stage of a dual-stage hypocycloidal reducer based on the
desired ratio and maximum desired number of pins, assuming:
 1. The input is an eccentric cam through stage 1 and stage 2 lobes.
 2. The stage 1 pins are rigidly held.
 3. The stage 1 and stage 2 lobes are mounted to each other.
 4. Eccentricity is the same in both stages (pin circle center point to lobe center point).
 5. The stage 2 pins are mounted such that their center point rotates about the input axis.
 6. The stage 2 pins are the output.

The "pin jump" values indicate how many pins the lobe teeth jump over per revolution.

The ratio may be any real number. A negative ratio will generate values
resulting in an output that spins the opposite direction of the input.
For example, entering -17.5 will generate a 17.5:1 reduction whose
output spins opposite the input.'''
	
print '\n Enter ratio: ',
ratio = float(raw_input())
print '\n Enter max number of pins: ',
maxpin = int(raw_input())
sol_count = 1
test_count = 0
solutions = 0

for looper1 in xrange (3, maxpin):
	L1 = float(looper1)
	for looper2 in xrange (4, maxpin + 1):
		P1 = float(looper2)
		for looper3 in xrange (3, maxpin):
			L2 = float(looper3)
			for looper4 in xrange (4, maxpin + 1):
				P2 = float(looper4)
				test_count += 1
				if (P1-L1 != 0) and (P2-L2 != 0) and (L1-L2 != 0) and (L1 != P1) and (P1 > L1) and (P2 > L2):
					check = (L1*P2)/((P2-L2)*(L1-L2))
					if (check == ratio) and (P1 - L1 == P2 - L2):
						solutions += 1
						if solutions == 1:
							print '\n\n Pin/lobe combinations:'
							print '\n\n      Stage 1:              Stage 2:'
							
						if P1 <= 9:P1_spaces = '  '
						else: P1_spaces = ' '
						if P2 <= 9: P2_spaces = '  '
						else: P2_spaces = ' '
						if L1 <= 9: L1_spaces = '  '
						else: L1_spaces = ' '
						if L2 <= 9: L2_spaces = '  '
						else: L2_spaces = ' '
						if sol_count <= 9: count_spaces = '  '
						else: count_spaces = ' '
						
					
						pinjump = P1 - L1
						
									
						print '\n%s%d. %s%d pins %s%d lobes    %s%d pins %s%d lobes   pin jump %d' % (count_spaces, sol_count, P1_spaces, P1, L1_spaces, L1, P2_spaces, P2, L2_spaces, L2, pinjump)
						
						sol_count += 1
						
if solutions == 0:
	
	print '\nNo solutions exist in %d tested combinations.\n' % test_count
else:
	if solutions == 1: sol_text = ' '
	else: sol_text = 's '
	print '\n\n %d solution%sfound. %d possible combinations tested.\n\n' % (solutions, sol_text, test_count)